@@ -1,7 +1,7 @@
 package CPAN::Reporter;
 use strict;
 use vars qw/$VERSION/;
-$VERSION = '1.1702'; 
+$VERSION = '1.1703'; 
 $VERSION = eval $VERSION; ## no critic
 
 use Config;
@@ -157,7 +157,7 @@ HERE
     $tee_input .= " $redirect" if defined $redirect;
     {
       # ensure autoflush if we can
-      local $ENV{PERL5OPT} = _get_perl5opt();
+      local $ENV{PERL5OPT} = _get_perl5opt() if _is_PL($command);
       tee($tee_input, { stderr => 1 }, $temp_out);
     }
 
@@ -596,7 +596,11 @@ sub _expand_result {
     my $result = shift;
     return if $result->{expanded}++; # only do this once
     $result->{prereq_pm} = _prereq_report( $result->{dist} );
-    $result->{env_vars} = _env_report();
+    {
+      # mirror PERL5OPT as in record_command
+      local $ENV{PERL5OPT} = _get_perl5opt() if _is_PL($result->{command});
+      $result->{env_vars} = _env_report();
+    }
     $result->{special_vars} = _special_vars_report();
     $result->{toolchain_versions} = _toolchain_report( $result );
     $result->{perl_version} = CPAN::Reporter::History::_format_perl_version();
@@ -630,8 +634,6 @@ my @env_vars= qw(
 
 sub _env_report {
     my @vars_found;
-    # mirror PERL5OPT as in record_command
-    local $ENV{PERL5OPT} = _get_perl5opt();
     for my $var ( @env_vars ) {
         if ( $var =~ m{^/(.+)/$} ) {
             push @vars_found, grep { /$1/ } keys %ENV;
@@ -768,6 +770,15 @@ sub _is_make {
     return $command =~ m{\b(?:\S*make|Makefile.PL)\b}ims ? 1 : 0;
 }
 
+#--------------------------------------------------------------------------#
+# _is_PL
+#--------------------------------------------------------------------------#
+
+sub _is_PL {
+  my $command = shift;
+  return $command =~ m{\b(?:Makefile|Build)\.PL\b}ims ? 1 : 0;
+}
+
 #--------------------------------------------------------------------------#
 # _max_length
 #--------------------------------------------------------------------------#
@@ -912,21 +923,22 @@ sub _prereq_report {
 
     # generate the report
     for my $section ( @prereq_sections ) {
-        if ( keys %{ $need{$section} } ) {
-            $report .= "$section:\n\n";
-            $report .= sprintf( $format_str, " ", qw/Module Need Have/ );
-            $report .= sprintf( $format_str, " ", 
-                                 "-" x $name_width, 
-                                 "-" x $need_width,
-                                 "-" x $have_width );
-        }
-        for my $module ( sort { lc $a cmp lc $b } keys %{ $need{$section} } ) {
-            my $need = $need{$section}{$module};
-            my $have = $have{$section}{$module};
-            my $bad = $prereq_met{$section}{$module} ? " " : "!";
-            $report .= 
-                sprintf( $format_str, $bad, $module, $need, $have);
+      if ( keys %{ $need{$section} } ) {
+        $report .= "$section:\n\n";
+        $report .= sprintf( $format_str, " ", qw/Module Need Have/ );
+        $report .= sprintf( $format_str, " ", 
+          "-" x $name_width, 
+          "-" x $need_width,
+          "-" x $have_width );
+        for my $module (sort {lc $a cmp lc $b} keys %{ $need{$section} } ) {
+          my $need = $need{$section}{$module};
+          my $have = $have{$section}{$module};
+          my $bad = $prereq_met{$section}{$module} ? " " : "!";
+          $report .= 
+          sprintf( $format_str, $bad, $module, $need, $have);
         }
+        $report .= "\n"; 
+      }
     }
     
     return $report || "    No requirements found\n";
